class Url {
  static final Url _instance = Url();

  static Url get instance => _instance;

  String host() {
  // return '192.168.10.183:3000';
    // return 'agusandelnorte.gov.ph';
    // return "192.168.10.219:3000";
    //  return "192.168.10.241";
      return "192.168.10.221:3004";
    // return "playweb.agusandelnorte.gov.ph";
    // return 'devapi.agusandelnorte.gov.ph:3004';
  }

  String authentication() {
    return '/api/account/auth/login/';
  }

  String profileInformation(){
    return 'api/jobnet_app/profile/pds/';
  }

  String latestApk(){
    return "/api/system_app/apk_version/latest";
  }

  ////SOS paths
  String sosRequest(){
    return "/api/sos_app/sos_request/";
  }

  //// DOCSMS paths
  String getDocument(){
    return "/api/web_app/public/document_viewer/";
  }

////ELIGIBILITIES PATHS
String eligibilities(){
  return "/api/jobnet_app/eligibilities/";
}

String getEligibilities(){
  return "/api/jobnet_app/profile/pds/eligibility/";
}

String addEligibility(){
  return "/api/jobnet_app/profile/pds/eligibility/";
}
String deleteEligibility(){
  return "/api/jobnet_app/profile/pds/eligibility/";
}

String updateEligibility(){
  return "/api/jobnet_app/profile/pds/eligibility/";
}
//// work history paths
String workhistory(){
  return "/api/jobnet_app/profile/pds/work/";
}
String getPositions(){
  return "/api/jobnet_app/positions/";
}
String getAgencies(){
    return "/api/jobnet_app/agencies/";
}

String getAgencyCategory(){
  return "api/jobnet_app/agency_categories/";
}

String identifications(){
  return "/api/jobnet_app/profile/pds/basic/identification/";
}


////educational background paths
String educationalBackground(){
  return "/api/jobnet_app/profile/pds/education/";
}
String getSchools(){
  return "/api/jobnet_app/schools/";
}
String getPrograms(){
  return "api/jobnet_app/education_programs/";
}
String getHonors(){
  return "/api/jobnet_app/honors";
}

//// learning and development paths

String learningAndDevelopments(){
  return "api/jobnet_app/profile/pds/learning_development/";
}
String conductedTrainings(){
  return "api/jobnet_app/conducted_trainings/";
}
String learningAndDevelopmentType(){
  return "api/jobnet_app/learning_development/";
}
String learningAndDevelopmentTopics(){
  return "api/jobnet_app/training_topics/";
}

//// references paths
String reference(){
  return "/api/jobnet_app/profile/pds/personal_reference/";
}


////voluntary works
String getVoluntaryWorks(){
  return "/api/jobnet_app/profile/pds/voluntary_work/";
}

//// skills hobbies
String skillsHobbies(){
  return "/api/jobnet_app/profile/pds/other/skill_hobby/";
}
String getAllSkillsHobbies(){
  return "/api/jobnet_app/skill_hobby/";
}
//// orgmemberships
String getOrgMemberShips(){
  return "/api/jobnet_app/profile/pds/other/org_membership/";
}

////non academic recognition
String getNonAcademicRecognition(){
  return "/api/jobnet_app/profile/pds/other/non_acad_recognition/";
}

////citizenship
String citizenship(){
  return "/api/jobnet_app/profile/pds/basic/citizenship/";
}

////family paths
String getFamilies(){
  return "/api/jobnet_app/profile/pds/family/";
}
String addEmergency(){
  return "/api/profile_app/person_emergency/";
}
String getRelationshipTypes(){
  return "/api/jobnet_app/relationship_types";
}
String updatePersonalInfor(){
  return "/api/jobnet_app/profile/pds/basic/personal/";
}


//// contacts path
String getServiceTypes(){
  return "/api/jobnet_app/comm_service_type/";

}
//// address path
String addressPath(){
  return "/api/jobnet_app/profile/pds/basic/address/";
}

String contactPath(){
  return "/api/jobnet_app/profile/pds/basic/contact/";
}
String getCommunicationProvider(){
  return "/api/jobnet_app/comm_services/";
}
String deleteContact (){
  return "/api/jobnet_app/profile/pds/basic/contact/";
}
////profile other info
String getReligions(){
  return "/api/profile_app/religion/";
}
String getEthnicity(){
  return "/api/profile_app/ethnicity/";
}

String getDisability(){
  return "api/profile_app/disability/";
}

String getIndigency(){
  return "/api/profile_app/indigenous/";
}

String getGenders(){
  return "/api/profile_app/gender/";
}


  //// location utils path
  String getCounties(){
    return "/api/jobnet_app/countries/";
  }
  String getRegions(){
    return "/api/web_app/location/region/";
  }
  String getProvinces(){
    return "api/web_app/location/province/";
  }
  String getCities(){
    return "/api/web_app/location/citymun/";
  }
  String getBarangays(){
    return "/api/web_app/location/barangay/";
  }
  String getAddressCategory(){
    return "/api/jobnet_app/address_categories/";
  }
}